#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <sys/time.h>
#include <sys/resource.h>
#include "cblas.h"

#define dumb_rand() ( 0.5 - ((double)rand())/((double)RAND_MAX) )

void ATL_sset(const int N, const float alpha, float *X, const int incX);
void ATL_szero(const int N, float *X, const int incX);

static double time00(void)
{
   struct rusage ruse;
   getrusage(RUSAGE_SELF, &ruse);
   return( (double)(ruse.ru_utime.tv_sec+ruse.ru_utime.tv_usec/1000000.0) );
}

void PrintUsage(char *nam)
{
   fprintf(stderr, "USAGE: %s [N]\n", nam);
}
main(int nargs, char **args)
{
   int N=1000, *ipiv;
   float *A, *B, *C;
   double mf, t0, t1;

   if (nargs > 1) N = atoi(args[1]);
   else N = 1000;

   A = malloc(N*N*sizeof(float));
   assert(A);
   ipiv = malloc(N*sizeof(int));
   assert(ipiv);
   ATL_szero(N*N, A, 1);
   ATL_sset(N, 1.0f, A, N+1);
   mf = ((2.0*N)*N*N) / 3000000.0;

   while(1)
   {
      t0 = time00();
      clapack_sgetrf(CblasColMajor, N, N, A, N, ipiv);
      t1 = time00() - t0;
      printf("time=%f, mflop=%f\n", t1, mf / t1);
   }
   free(A);
   free(ipiv);
   exit(0);
}
